@@ -7,7 +7,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -464,77 +464,153 @@ function m3CancelSafeContentEdit()
 /**
  * 画面操作用スライド開閉メニューバー
  */
-(function($){
-	$.fn.m3SlideMenubar = function(givenOpts){
-		opts = $.extend({
-			position: 'top',			// panel position 'top' or 'bottom'
-			height: '80px',				// set the height of the panel
-			speed: 'normal',			// 'slow', 'normal', 'fast', or number in milliseconds
-			touchPanel: true,			// mouse click operation than mouse hover
-			openBtn: '.m3open',			// open button id or class inside 'slidetrigger' div
-			closeBtn: '.m3close',			// close button id or class inside 'slidetrigger' div
-			slideTrigger: '#slidetrigger'	// trigger id or class
-		}, givenOpts);
+$.fn.m3SlideMenubar = function(givenOpts){
+	opts = $.extend({
+		position: 'top',			// panel position 'top' or 'bottom'
+		height: '80px',				// set the height of the panel
+		speed: 'normal',			// 'slow', 'normal', 'fast', or number in milliseconds
+		touchPanel: true,			// mouse click operation than mouse hover
+		openBtn: '.m3open',			// open button id or class inside 'slidetrigger' div
+		closeBtn: '.m3close',			// close button id or class inside 'slidetrigger' div
+		slideTrigger: '#slidetrigger'	// trigger id or class
+	}, givenOpts);
 
-		// refers to the selector 'm3SlideMenubar'
-		var $this = $(this);
+	// refers to the selector 'm3SlideMenubar'
+	var $this = $(this);
 
-		// vars needed to pass args to animate method
-		var containerpadding;
-		var aniOpenArgs = {};
-		var aniCloseArgs = {};
+	// vars needed to pass args to animate method
+	var containerpadding;
+	var aniOpenArgs = {};
+	var aniCloseArgs = {};
 
-		// add appropriate class names based on position
-		if (opts.position == 'top') {
-			$this.addClass('top');
-			$(opts.slideTrigger).addClass('top');
-			containerpadding = 'top';
-		} else {
-			$this.addClass('bottom');
-			$(opts.slideTrigger).addClass('bottom');
-			containerpadding = 'padding-bottom';
-		};
-
-		// set panel's height
-		$this.css('height', opts.height);
-
-		// remove the 'px' from the height string so we can calculate the container padding
-		var newpadding = opts.height.replace("px","");
-		newpadding = parseInt(opts.height) + 21;
-
-		aniOpenArgs[containerpadding] = newpadding;
-		aniCloseArgs[containerpadding] = 0;
-
-		if (opts.touchPanel){
-			// slide panel in and container down
-			$(opts.openBtn).click(function(){
-				$this.slideDown(opts.speed);
-				$(opts.slideTrigger).animate(aniOpenArgs, opts.speed);
-				$(opts.openBtn).css({'display':'none'});
-				$(opts.closeBtn).css({'display':'inline'});
-				return false;
-			});
-			// slide panel out and container up
-			$(opts.closeBtn).click(function(){
-				$this.slideUp(opts.speed);
-				$(opts.slideTrigger).animate(aniCloseArgs, opts.speed);
-				$(opts.openBtn).css({'display':'inline'});
-				$(opts.closeBtn).css({'display':'none'});
-				return false;
-			});
-		} else {
-			// slide panel in and container down
-			$(opts.openBtn).mouseover(function(){
-				$this.slideDown(opts.speed);
-				$(opts.slideTrigger).slideUp(opts.speed);
-				return false;
-			});
-			// slide panel out and container up
-			$this.hover(function(){},function(){
-				$this.slideUp(opts.speed);
-				$(opts.slideTrigger).slideDown(opts.speed);
-				return false;
-			});
-		}
+	// add appropriate class names based on position
+	if (opts.position == 'top') {
+		$this.addClass('top');
+		$(opts.slideTrigger).addClass('top');
+		containerpadding = 'top';
+	} else {
+		$this.addClass('bottom');
+		$(opts.slideTrigger).addClass('bottom');
+		containerpadding = 'padding-bottom';
 	};
-})(jQuery);
+
+	// set panel's height
+	$this.css('height', opts.height);
+
+	// remove the 'px' from the height string so we can calculate the container padding
+	var newpadding = opts.height.replace("px","");
+	newpadding = parseInt(opts.height) + 21;
+
+	aniOpenArgs[containerpadding] = newpadding;
+	aniCloseArgs[containerpadding] = 0;
+
+	if (opts.touchPanel){
+		// slide panel in and container down
+		$(opts.openBtn).click(function(){
+			$this.slideDown(opts.speed);
+			$(opts.slideTrigger).animate(aniOpenArgs, opts.speed);
+			$(opts.openBtn).css({'display':'none'});
+			$(opts.closeBtn).css({'display':'inline'});
+			return false;
+		});
+		// slide panel out and container up
+		$(opts.closeBtn).click(function(){
+			$this.slideUp(opts.speed);
+			$(opts.slideTrigger).animate(aniCloseArgs, opts.speed);
+			$(opts.openBtn).css({'display':'inline'});
+			$(opts.closeBtn).css({'display':'none'});
+			return false;
+		});
+	} else {
+		// slide panel in and container down
+		$(opts.openBtn).mouseover(function(){
+			$this.slideDown(opts.speed);
+			$(opts.slideTrigger).slideUp(opts.speed);
+			return false;
+		});
+		// slide panel out and container up
+		$this.hover(function(){},function(){
+			$this.slideUp(opts.speed);
+			$(opts.slideTrigger).slideDown(opts.speed);
+			return false;
+		});
+	}
+};
+/*
+ * 初期処理
+ */
+$(function(){
+	//** jQuery Scroll to Top Control script- (c) Dynamic Drive DHTML code library: http://www.dynamicdrive.com.
+	//** Available/ usage terms at http://www.dynamicdrive.com (March 30th, 09')
+	//** v1.1 (April 7th, 09'):
+	//** 1) Adds ability to scroll to an absolute position (from top of page) or specific element on the page instead.
+	//** 2) Fixes scroll animation not working in Opera. 
+	var scrolltotop={
+		//startline: Integer. Number of pixels from top of doc scrollbar is scrolled before showing control
+		//scrollto: Keyword (Integer, or "Scroll_to_Element_ID"). How far to scroll document up when control is clicked on (0=top).
+		setting: {startline:100, scrollto: 0, scrollduration:1000, fadeduration:[500, 100]},
+		controlHTML: '<img src="' + M3_ROOT_URL + '/images/system/gotop48.png" style="width:48px; height:48px" />', //HTML for control, which is auto wrapped in DIV w/ ID="topcontrol"
+		controlattrs: {offsetx:5, offsety:5}, //offset of control relative to right/ bottom of window corner
+		anchorkeyword: '#top', //Enter href value of HTML anchors on the page that should also act as "Scroll Up" links
+
+		state: {isvisible:false, shouldvisible:false},
+
+		scrollup:function(){
+			if (!this.cssfixedsupport) //if control is positioned using JavaScript
+				this.$control.css({opacity:0}) //hide control immediately after clicking it
+			var dest=isNaN(this.setting.scrollto)? this.setting.scrollto : parseInt(this.setting.scrollto)
+			if (typeof dest=="string" && $('#'+dest).length==1) //check element set by string exists
+				dest=$('#'+dest).offset().top
+			else
+				dest=0
+			this.$body.animate({scrollTop: dest}, this.setting.scrollduration);
+		},
+
+		keepfixed:function(){
+			var $window=$(window)
+			var controlx=$window.scrollLeft() + $window.width() - this.$control.width() - this.controlattrs.offsetx
+			var controly=$window.scrollTop() + $window.height() - this.$control.height() - this.controlattrs.offsety
+			this.$control.css({left:controlx+'px', top:controly+'px'})
+		},
+
+		togglecontrol:function(){
+			var scrolltop=$(window).scrollTop()
+			if (!this.cssfixedsupport)
+				this.keepfixed()
+			this.state.shouldvisible=(scrolltop>=this.setting.startline)? true : false
+			if (this.state.shouldvisible && !this.state.isvisible){
+				this.$control.stop().animate({opacity:1}, this.setting.fadeduration[0])
+				this.state.isvisible=true
+			}
+			else if (this.state.shouldvisible==false && this.state.isvisible){
+				this.$control.stop().animate({opacity:0}, this.setting.fadeduration[1])
+				this.state.isvisible=false
+			}
+		},
+	
+		init:function(){
+			$(document).ready(function($){
+				var mainobj=scrolltotop
+				var iebrws=document.all
+				mainobj.cssfixedsupport=!iebrws || iebrws && document.compatMode=="CSS1Compat" && window.XMLHttpRequest //not IE or IE7+ browsers in standards mode
+				mainobj.$body=(window.opera)? (document.compatMode=="CSS1Compat"? $('html') : $('body')) : $('html,body')
+				mainobj.$control=$('<div id="topcontrol">'+mainobj.controlHTML+'</div>')
+					.css({position:mainobj.cssfixedsupport? 'fixed' : 'absolute', bottom:mainobj.controlattrs.offsety, right:mainobj.controlattrs.offsetx, opacity:0, cursor:'pointer'})
+					.attr({title:'先頭へスクロール'})
+					.click(function(){mainobj.scrollup(); return false})
+					.appendTo('body')
+				if (document.all && !window.XMLHttpRequest && mainobj.$control.text()!='') //loose check for IE6 and below, plus whether control contains any text
+					mainobj.$control.css({width:mainobj.$control.width()}) //IE6- seems to require an explicit width on a DIV containing text
+				mainobj.togglecontrol()
+				$('a[href="' + mainobj.anchorkeyword +'"]').click(function(){
+					mainobj.scrollup()
+					return false
+				})
+				$(window).bind('scroll resize', function(e){
+					mainobj.togglecontrol()
+				})
+			})
+		}
+	}
+	scrolltotop.init()
+});
