@@ -16,9 +16,9 @@
 	window.m3 = {};
 	var m3InsertIndex = -1;
 	var m3UpdatePos;
-	const DRAG_ITEM_WIDTH = '200px';		// ドラッグ中のウィジェットの幅
-	const PANEL_WIDTH = '240';				// パネル幅
-	const CURSOR_OFFSET = 10;				// カーソルの位置
+	var DRAG_ITEM_WIDTH = '200px';		// ドラッグ中のウィジェットの幅
+	var PANEL_WIDTH = '240';				// パネル幅
+	var CURSOR_OFFSET = 10;				// カーソルの位置
 	
 	var m3UpdateByConfig = function(serial){
 		var widgets = $('.m3_widget_sortable');
@@ -430,7 +430,7 @@
 		widgetWindow += '</ul>';
 		widgetWindow += '<div id="m3paneltab_widget">';
 		widgetWindow += '<div class="m3message"></div>';
-		widgetWindow += '<div id="m3paneltab_widget_list" class="m3widgetlist" style="overflow: auto;">';
+		widgetWindow += '<div id="m3paneltab_widget_list" class="m3widgetlist">';
 		
 /*		widgetWindow += '<dl class="m3accordion">';
 		widgetWindow += '<dt>Heading 1</dt>';
