@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_update_boxWidgetContainer.php 3918 2011-01-01 03:20:22Z fishbone $
+ * @version    SVN: $Id: blog_update_boxWidgetContainer.php 5267 2012-10-04 11:33:36Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -20,7 +20,6 @@ require_once($gEnvManager->getCommonPath()			. '/htmlEdit.php');
 class blog_update_boxWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $isEntry;	// 記事の投稿があるかどうか
 	private $defaultUrl;	// システムのデフォルトURL
 	private $headRssFile;				// RSS情報
@@ -40,7 +39,6 @@ class blog_update_boxWidgetContainer extends BaseWidgetContainer
 		
 		// DB接続オブジェクト作成
 		$this->db = new blog_update_boxDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -67,8 +65,6 @@ class blog_update_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		
 		// 設定値を取得
 		$itemCount = self::DEFAULT_ITEM_COUNT;	// 表示項目数
 		$useRss = 1;							// RSS配信を行うかどうか
@@ -84,7 +80,7 @@ class blog_update_boxWidgetContainer extends BaseWidgetContainer
 		
 		// 新規ブログタイトルを取得
 		$this->defaultUrl = $this->gEnv->getDefaultUrl();
-		$this->db->getEntryItems($itemCount, $this->gEnv->getCurrentLanguage(), $now, array($this, 'itemLoop'));
+		$this->db->getEntryItems($itemCount, $this->gEnv->getCurrentLanguage(), array($this, 'itemLoop'));
 			
 		if (!$this->isEntry){	// 記事の投稿がないときはメッセージを出力
 			$this->tmpl->addVar("_widget", "message", '投稿記事はありません');
